/*
 *   Copyright (c) 1994 by
 *   PARALLAX GRAPHICS, INCORPORATED, Santa Clara, California.
 *   All rights reserved
 *
 *   This software is furnished on an as-is basis, and may be used and copied
 *   only with the inclusion of the above copyright notice.
 *
 *   The information in this software is subject to change without notice.
 *   No committment is made as to the usability or reliability of this
 *   software.
 *
 *   Parallax Graphics, Inc.
 *   2500 Condensa Street
 *   Santa Clara, California  95051
 */

/*
** File:
**
**  Xvimageproto.h: Definitions for image extensions to Xv protocol.
**                These extensions utilize the XvControl request.
**
** Author:
**
**   Andy Goodrich (Parallax)
**
** Revisions:
**
**   05.01.95 Goodrich
**     - Initial coding.
*/
#ifndef Xvimageproto_h_INCLUDED
#define Xvimageproto_h_INCLUDED

/*  GENERIC GET IMAGE REQUEST
 *
 *  (This is piggy-backed as a device-dependent xv operation.)
 */
#define xv_GetImage xv_Control

typedef struct _xvGetImageReq {
    CARD8 		reqType;	    /* <-+- These first 5 fields are xvControl. */
    CARD8 		xvReqType;      /*   |                                      */
    CARD16 		length B16;     /*   |                                      */
    XvPortID 	port B32;       /*   |                                      */
    Atom 		attribute B32;  /* <-+                                      */

    Drawable 	drawable B32; /* Start of device-dependent request info. */
    GContext 	gc B32;
    CARD8       xvImageType;
    CARD8       sendEvent;
    INT16 		src_x B16;
    INT16		src_y B16;
    CARD16 		src_w B16;
    CARD16		src_h B16;
    CARD16      dst_w B16;
    CARD16      dst_h B16;
} xvGetImageReq;
#define sz_xvGetImageReq        (sizeof(xvGetImageReq)) /* 56 */

typedef struct { 
    BYTE type;  /* X_Reply */
    CARD8 depth;
    CARD16 sequenceNumber B16;
    CARD32 length B32;
    VisualID visual B32;
    CARD32 size B32;
    CARD32 pad4 B32;
    CARD32 pad5 B32;
    CARD32 pad6 B32;
    CARD32 pad7 B32;
    } xvGetImageReply;
#define sz_xvGetImageReply   32


/*  GENERIC PUT IMAGE REQUEST
 *
 *  (This is piggy-backed as a device-dependent xv operation.)
 */
#define xv_PutImage xv_Control

typedef struct _xvPutImageReq {
    CARD8 		reqType;	    /* <-+- These first 5 fields are xvControl. */
    CARD8 		xvReqType;      /*   |                                      */
    CARD16 		length B16;     /*   |                                      */
    XvPortID 	port B32;       /*   |                                      */
    Atom 		attribute B32;  /* <-+                                      */

    Drawable 	drawable B32; /* Start of device-dependent request info. */
    GContext 	gc B32;
    CARD8       xvImageType;
    CARD8       sendEvent;
    INT16 		src_x B16;
    INT16		src_y B16;
    CARD16 		src_w B16;
    CARD16		src_h B16;
	INT16		dst_x B16;
	INT16		dst_y B16;
    CARD16      dst_w B16;
    CARD16      dst_h B16;
} xvPutImageReq;
#define sz_xvPutImageReq        (sizeof(xvPutImageReq)) /* 38 */

typedef struct { 
    BYTE type;  /* X_Reply */
    CARD8 depth;
    CARD16 sequenceNumber B16;
    CARD32 length B32;
    VisualID visual B32;
    CARD32 size B32;
    CARD32 pad4 B32;
    CARD32 pad5 B32;
    CARD32 pad6 B32;
    CARD32 pad7 B32;
    } xvPutImageReply;
#define sz_xvPutImageReply   32

#endif  /* Xvimageproto_h_INCLUDED */
