/*
** File:
**
**   xvdebug.h --- Macros to produce debugging and error messages for xv.
**                 Messages are written to the file /usr/local/xv/xv_log.
**                 Debugging may be turned off at compile time by failing
**                 to define XV_DIAG. Note that changing the value of 
**                 XV_DIAG may be used to provide up to 32 different
**                 debugging message enables.
**
** Author:
**
**   Andy Goodrich (RasterOps)
**
** Revisions:
**
**   08.08.92 Andy Goodrich
**     - Initial Definition.
**
** $Log:	xvdebug.h,v $
** Revision 1.1  95/05/02  11:55:53  11:55:53  dist ()
** Initial revision
** 
*/

#ifndef xvdebug_INCLUDED
#define xvdebug_INCLUDED
/*
 *  DEBUGGING AND ERROR MACROS
 */
#ifdef XV_DIAG
#ifndef XV_DIAG_PREFIX
#define XV_DIAG_PREFIX
#endif
static int	debug_temp;		/* Temporary for stuff. */
#   define DEBUGF( level, args ) \
    {\
        if ( level & XV_DIAG ) \
        { \
            FILE *fd;  \
            fd = stderr; \
			XV_DIAG_PREFIX; \
            fprintf args; \
            fd = fopen("/tmp/xv_log", "a+");\
            if ( fd ) \
			{ \
				XV_DIAG_PREFIX; \
				fprintf args ; \
			} \
            fclose(fd); \
        } \
    }
#   define ERRORF( args ) DEBUGF( 0xFFFFFFFF, args )
#else  /* !XV_DIAG */
#   define DEBUGF( level, args )
#   define ERRORF( args ) \
    { \
        FILE *fd = stderr; \
        fprintf args; \
    }
#endif /* XV_DIAG */

#endif  /* xvdebug_INCLUDED */
